Hanna - Turning your configurations into actions
================================================

Inspired by `anna <https://pypi.org/project/anna/>`__ -- revised and refurbished,
uses `HOCON <https://github.com/lightbend/config/blob/master/HOCON.md>`__
via `pyhocon <https://pypi.org/project/pyhocon/>`__.

----

.. note::
   This project's
   `development <https://gitlab.com/Dominik1123/Hanna/issues?scope=all&utf8=%E2%9C%93&state=opened&label_name[]=feature-proposal>`__
   is
   `documentation <https://dominik1123.gitbook.io/hanna>`__
   `driven <http://lmgtfy.com/?s=d&q=Documentation+Driven+Development>`__.

Helpful links
-------------

* `Documentation <https://dominik1123.gitbook.io/hanna>`__
* `Features under construction <https://gitlab.com/Dominik1123/Hanna/issues?scope=all&utf8=%E2%9C%93&state=opened&label_name[]=feature-proposal>`__
